query dimInfo-objects depending on argument type
Source: R/generics_dimInfo.r, R/methods_class_dimInfo.r
get.dimInfo-method.Rdquery dimInfo-objects depending on argument type
Arguments
- object
an object of class
dataObj- type
a character vector of length 1 defining what to calculate|return|modify. Allowed types are:
strInfo: info on how many digits in the default codes ach dimensional variable allocates
dimInfo: a list object with each slot containing an object of class
dimVarvarName: variable names
strID: character vector of ID's defining table cells
posIndex vector showing the index of the elements of
dimInfoin the underlying data
Value
information from objects of class dimInfo depending on argument type
a list (or NULL) if argument
typematches 'strInfo', 'dimInfo'numeric vector (or NULL) if argument
typematches 'posIndex'character vector (or NULL) if argument
typematches 'varName' or 'strID'
Author
Bernhard Meindl bernhard.meindl@statistik.gv.at