allows to run batch-files for tau argus given the path to an executable of argus.
The provided batch input files can either be created using function createArgusInput or
can be arbitrarily created. In the latter case, argument obj should not be specified and not output
is returned, the script is just executed in tau-argus.
Usage
runArgusBatchFile(
obj = NULL,
batchF,
exe = "C:\\Tau\\TauArgus.exe",
batchDataDir = NULL,
verbose = FALSE
)Arguments
- obj
NULLor an object of classsdcProblem-classthat was used to generate the batchfile for argus. If notNULL, this object is used to create correct variable names. Else, only the output from tau-Argus is read and returned as adata.table. In this case it is possible to run tau-Argus on arbitrarily created batch-files.- batchF
a filepath to an batch-input file created by e.g.
createArgusInput.- exe
(character) file-path to tau-argus executable
- batchDataDir
if different from
NULL, this directory is used to look for input-file and writes output files to. This helps to use relative paths in batch input files.- verbose
(logical) if
TRUE, some additional information is printed to the prompt